| Title: | An Extension (for Package 'SigTree') of Some of the Classes in Package 'phylobase' |
|---|---|
| Description: | Based on (but not identical to) the no-longer-maintained package 'phyext', provides enhancements to 'phylobase' classes, specifically for use by package 'SigTree'; provides classes and methods which help users manipulate branch-annotated trees (as in 'SigTree'); also provides support for a few other extra features. |
| Authors: | J. Conrad Stack |
| Maintainer: | John R. Stevens <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.4 |
| Built: | 2026-05-21 10:24:02 UTC |
| Source: | https://github.com/cran/phyext2 |
Internal functions, classes, and methods (from the no-longer-maintained phyext package) used indirectly by the export.figtree function of the SigTree package.
The export.figtree function of the SigTree package depends on several functions in the previously-maintained phyext package.
In December 2014, that package's maintainer declined to continue maintenance, and that package was dropped from CRAN.
With the permission of that package's original author (Conrad Stack), the tools of the phyext package are included here.
The original phyext package can be found in the CRAN archives:
http://cran.r-project.org/src/contrib/Archive/phyext/
J. Conrad Stack
J. Conrad Stack (2011). "phyext: An extension of some of the classes in phylobase. Tree objects now support subnodes on branches." R package version 0.0.1.
# dummy example x <- 1# dummy example x <- 1
Internal functions, classes, and methods (from the no-longer-maintained phyext package) used indirectly by the export.figtree function of the SigTree package.
The export.figtree function of the SigTree package depends on several functions in the previously-maintained phyext package.
In December 2014, that package's maintainer declined to continue maintenance, and that package was dropped from CRAN.
With the permission of that package's original author (Conrad Stack), the tools of the phyext package are included here.
The original phyext package can be found in the CRAN archives:
http://cran.r-project.org/src/contrib/Archive/phyext/
J. Conrad Stack
J. Conrad Stack (2011). "phyext: An extension of some of the classes in phylobase. Tree objects now support subnodes on branches." R package version 0.0.1.
# dummy example x <- 1# dummy example x <- 1
Internal functions, classes, and methods (from the no-longer-maintained phyext package) used indirectly by the export.figtree function of the SigTree package.
The export.figtree function of the SigTree package depends on several functions in the previously-maintained phyext package.
In December 2014, that package's maintainer declined to continue maintenance, and that package was dropped from CRAN.
With the permission of that package's original author (Conrad Stack), the tools of the phyext package are included here.
The original phyext package can be found in the CRAN archives:
http://cran.r-project.org/src/contrib/Archive/phyext/
J. Conrad Stack
J. Conrad Stack (2011). "phyext: An extension of some of the classes in phylobase. Tree objects now support subnodes on branches." R package version 0.0.1.
# dummy example x <- 1# dummy example x <- 1