Welcome to ClientVPS Mirrors

Help for package phyext2
Type: Package
Title: An Extension (for Package 'SigTree') of Some of the Classes in Package 'phylobase'
Version: 0.0.4
Date: 2015-07-27
Author: J. Conrad Stack
Maintainer: John R. Stevens <john.r.stevens@usu.edu>
Imports: methods, phylobase, ape, grid, stats
Description: Based on (but not identical to) the no-longer-maintained package 'phyext', provides enhancements to 'phylobase' classes, specifically for use by package 'SigTree'; provides classes and methods which help users manipulate branch-annotated trees (as in 'SigTree'); also provides support for a few other extra features.
License: GPL-3
NeedsCompilation: no
Packaged: 2015-07-27 18:45:56 UTC; John
Repository: CRAN
Date/Publication: 2015-07-27 23:38:32

Misc. functions from phyext package

Description

Internal functions, classes, and methods (from the no-longer-maintained phyext package) used indirectly by the export.figtree function of the SigTree package.

Details

The export.figtree function of the SigTree package depends on several functions in the previously-maintained phyext package. In December 2014, that package's maintainer declined to continue maintenance, and that package was dropped from CRAN. With the permission of that package's original author (Conrad Stack), the tools of the phyext package are included here.

The original phyext package can be found in the CRAN archives: http://cran.r-project.org/src/contrib/Archive/phyext/

Author(s)

J. Conrad Stack

References

J. Conrad Stack (2011). "phyext: An extension of some of the classes in phylobase. Tree objects now support subnodes on branches." R package version 0.0.1.

Examples

# dummy example
x <- 1

Misc. functions from phyext package (class definitions)

Description

Internal functions, classes, and methods (from the no-longer-maintained phyext package) used indirectly by the export.figtree function of the SigTree package.

Details

The export.figtree function of the SigTree package depends on several functions in the previously-maintained phyext package. In December 2014, that package's maintainer declined to continue maintenance, and that package was dropped from CRAN. With the permission of that package's original author (Conrad Stack), the tools of the phyext package are included here.

The original phyext package can be found in the CRAN archives: http://cran.r-project.org/src/contrib/Archive/phyext/

Author(s)

J. Conrad Stack

References

J. Conrad Stack (2011). "phyext: An extension of some of the classes in phylobase. Tree objects now support subnodes on branches." R package version 0.0.1.

Examples

# dummy example
x <- 1

Misc. functions from phyext package (methods definitions)

Description

Internal functions, classes, and methods (from the no-longer-maintained phyext package) used indirectly by the export.figtree function of the SigTree package.

Details

The export.figtree function of the SigTree package depends on several functions in the previously-maintained phyext package. In December 2014, that package's maintainer declined to continue maintenance, and that package was dropped from CRAN. With the permission of that package's original author (Conrad Stack), the tools of the phyext package are included here.

The original phyext package can be found in the CRAN archives: http://cran.r-project.org/src/contrib/Archive/phyext/

Author(s)

J. Conrad Stack

References

J. Conrad Stack (2011). "phyext: An extension of some of the classes in phylobase. Tree objects now support subnodes on branches." R package version 0.0.1.

Examples

# dummy example
x <- 1

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.